@@ -4,15 +4,16 @@ from typing import Optional
 
 from qdrant_client import QdrantClient
 
+from wela_agents.schema.prompt.openai_chat import Message
+from wela_agents.embedding.embedding import Embedding
 from wela_agents.memory.openai_chat.qdrant_memory import QdrantMemory
 from wela_agents.memory.openai_chat.qdrant_memory import unique
 from wela_agents.memory.openai_chat.qdrant_memory import sort_key_id
 from wela_agents.memory.openai_chat.qdrant_memory import sort_key_score
-from wela_agents.schema.prompt.openai_chat import Message
 
 class WindowQdrantMemory(QdrantMemory):
-    def __init__(self, memory_key: str, qdrant_client: QdrantClient, limit: int=15, window_size: int = 5, score_threshold: Optional[float] = None) -> None:
-        super().__init__(memory_key, qdrant_client, limit, score_threshold)
+    def __init__(self, memory_key: str, embedding: Embedding, qdrant_client: QdrantClient, vector_size = 512, limit: int=15, window_size: int = 5, score_threshold: Optional[float] = None) -> None:
+        super().__init__(memory_key, embedding, qdrant_client, vector_size, limit, score_threshold)
         self.__limit: int = limit
         self.__window_size: int = window_size
 
